@@ -24,23 +24,22 @@
  */
 
 /*
- * G(NOME|TK) Scores Widget by Horacio J. Pea <horape@compendium.com.ar>
+ * G(NOME|TK) Scores Widget by Horacio J. Peña <horape@compendium.com.ar>
  *
  */
 
 #include <config.h>
-#include <libgnome/gnome-macros.h>
 
 #include <string.h>
 #include <time.h>
+
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
 
-#include "gnome-i18nP.h"
-
+#include <libgnome/gnome-macros.h>
 #include <libgnome/gnome-util.h>
 #include <libgnome/gnome-config.h>
 #include <libgnome/gnome-score.h>
-#include <libgnome/gnome-i18n.h>
 
 #include "gnome-scores.h"
 
@@ -58,9 +57,6 @@ struct _GnomeScoresPrivate
   guint	      n_scores;
 };
 
-static void gnome_scores_class_init (GnomeScoresClass *klass);
-static void gnome_scores_instance_init (GnomeScores      *scores);
-static void gnome_scores_destroy    (GtkObject        *object);
 static void gnome_scores_finalize   (GObject          *object);
 
 /**
@@ -69,9 +65,9 @@ static void gnome_scores_finalize   (GObject          *object);
  * Returns the GtkType for the GnomeScores widget
  */
 GNOME_CLASS_BOILERPLATE (GnomeScores, gnome_scores,
-			 GtkDialog, gtk_dialog, GTK_TYPE_DIALOG);
+			 GtkDialog, GTK_TYPE_DIALOG)
 
-static void 
+static void
 gnome_scores_instance_init (GnomeScores *gs)
 {
 	GtkWidget *label;
@@ -81,8 +77,8 @@ gnome_scores_instance_init (GnomeScores *gs)
 	gtk_window_set_title (GTK_WINDOW (gs), _("Top Ten"));
 
 	gtk_dialog_add_button (GTK_DIALOG (gs),
-			       GTK_STOCK_OK,
-			       GTK_RESPONSE_OK);
+			       GTK_STOCK_CLOSE,
+			       GTK_RESPONSE_CLOSE);
 
 	gs->_priv->logo = NULL;
 	gs->_priv->but_clear = NULL;
@@ -109,9 +105,9 @@ gnome_scores_instance_init (GnomeScores *gs)
 
 	gtk_container_set_border_width (GTK_CONTAINER (gs), 5);
 
-	gtk_signal_connect_object (GTK_OBJECT (gs), "response",
-				   GTK_SIGNAL_FUNC (gtk_widget_destroy),
-				   GTK_OBJECT (gs));
+	g_signal_connect_swapped (gs, "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  gs);
 
 	gs->_priv->logo_container = gtk_hbox_new(FALSE, 0);
 	gtk_widget_show(gs->_priv->logo_container);
@@ -124,63 +120,47 @@ gnome_scores_instance_init (GnomeScores *gs)
 static void
 gnome_scores_class_init (GnomeScoresClass *class)
 {
-	GtkObjectClass *object_class;
 	GObjectClass *gobject_class;
 
-	object_class = (GtkObjectClass *) class;
 	gobject_class = (GObjectClass *) class;
 
-	object_class->destroy = gnome_scores_destroy;
 	gobject_class->finalize = gnome_scores_finalize;
 }
 
-static void
-gnome_scores_destroy(GtkObject *object)
-{
-	GnomeScores *gs = GNOME_SCORES(object);
-
-	/* remember, destroy can be run multiple times! */
-
-	g_free(gs->_priv->label_names);
-	gs->_priv->label_names = NULL;
-	g_free(gs->_priv->label_scores);
-	gs->_priv->label_scores = NULL;
-	g_free(gs->_priv->label_times);
-	gs->_priv->label_times = NULL;
-
-	if(GTK_OBJECT_CLASS(parent_class)->destroy)
-		(* GTK_OBJECT_CLASS(parent_class)->destroy) (object);
-}
-
 static void
 gnome_scores_finalize(GObject *object)
 {
 	GnomeScores *gs = GNOME_SCORES(object);
 
-	g_free(gs->_priv);
+	g_free (gs->_priv->label_names);
+	gs->_priv->label_names = NULL;
+	g_free (gs->_priv->label_scores);
+	gs->_priv->label_scores = NULL;
+	g_free (gs->_priv->label_times);
+	gs->_priv->label_times = NULL;
+
+	g_free (gs->_priv);
 	gs->_priv = NULL;
 
-	if(G_OBJECT_CLASS(parent_class)->finalize)
-		(* G_OBJECT_CLASS(parent_class)->finalize) (object);
+	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 /**
  * gnome_scores_construct:
+ * @gs:
  * @n_scores: Number of positions.
  * @names: Names of the players.
  * @scores: Scores
  * @times: Time in which the scores were done
  * @clear: Add a "Clear" Button?
  *
- * Description: useful for language bindings and subclassing, not to be used by itself,
- * see #gnome_scores_new
- *
- * Returns:
+ * Description: useful for language bindings and subclassing, not to be used by
+ * itself, see #gnome_scores_new.
  */
 void
 gnome_scores_construct (  GnomeScores *gs,
-			  guint n_scores, 
-			  gchar **names, 
+			  guint n_scores,
+			  gchar **names,
 			  gfloat *scores,
 			  time_t *times,
 			  gboolean clear)
@@ -196,6 +176,8 @@ gnome_scores_construct (  GnomeScores *gs,
 	gs->_priv->label_times  = g_malloc(sizeof(GtkWidget*) * n_scores);
 
 	for(i=0; i < n_scores; i++) {
+		char *str_utf8;
+
 		gs->_priv->label_names[i] = gtk_label_new ( names[i] );
 		gtk_widget_show ( gs->_priv->label_names[i] );
 		gtk_table_attach_defaults ( gs->_priv->table, gs->_priv->label_names[i], 0, 1, i+1, i+2);
@@ -205,13 +187,9 @@ gnome_scores_construct (  GnomeScores *gs,
 		gtk_widget_show ( gs->_priv->label_scores[i] );
 		gtk_table_attach_defaults ( gs->_priv->table, gs->_priv->label_scores[i], 1, 2, i+1, i+2);
 
-		/* the localized string should fit (after replacing the %a %b
-		   etc) in ~18 chars.
-		   %a is abbreviated weekday, %A is full weekday,
-		   %b %B are abbreviated and full monthname, %Y is year,
-		   %d is day of month, %m is month number, %T full hour,
-		   %H hours, %M minutes, %S seconds
-		*/
+		/* TRANSLATORS NOTE: Date format used when showing scores in games.
+		 * Please refer to manpage of strftime(3) for complete reference.
+		 */
 		if(strftime(tmp2, sizeof(tmp2), _("%a %b %d %T %Y"),
 			    localtime( &(times[i]) )) == 0) {
 			/* according to docs, if the string does not fit, the
@@ -220,12 +198,15 @@ gnome_scores_construct (  GnomeScores *gs,
 			strcpy(tmp2, "???");
 		}
 		tmp2[sizeof(tmp2)-1] = '\0'; /* just for sanity */
-		gs->_priv->label_times[i] = gtk_label_new ( tmp2 );
+
+		str_utf8 = g_locale_to_utf8 (tmp2, -1, NULL, NULL, NULL);
+		gs->_priv->label_times[i] = gtk_label_new (str_utf8 ? str_utf8 : NULL);
+		g_free (str_utf8);
 		gtk_widget_show ( gs->_priv->label_times[i] );
 		gtk_table_attach_defaults ( gs->_priv->table, gs->_priv->label_times[i], 2, 3, i+1, i+2);
   	}
 
-	/* 
+	/*
 	if(clear) {
 	  gs->_priv->but_clear = gtk_button_new_with_label ( _("Clear") );
 	  gtk_widget_show (gs->_priv->but_clear);
@@ -246,14 +227,14 @@ gnome_scores_construct (  GnomeScores *gs,
  *
  * Returns: A new #GnomeScores widget
  */
-GtkWidget * 
-gnome_scores_new (  guint n_scores, 
-		    gchar **names, 
+GtkWidget *
+gnome_scores_new (  guint n_scores,
+		    gchar **names,
 		    gfloat *scores,
 		    time_t *times,
 		    gboolean clear)
 {
-	GtkWidget *retval = gtk_type_new (GNOME_TYPE_SCORES);
+	GtkWidget *retval = g_object_new (GNOME_TYPE_SCORES, NULL);
 
 	gnome_scores_construct(GNOME_SCORES(retval), n_scores, names, scores, times, clear);
 
@@ -267,8 +248,6 @@ gnome_scores_new (  guint n_scores,
  * @col: Color.
  *
  * Description: Set the color of one entry.
- *
- * Returns:
  */
 void
 gnome_scores_set_color(GnomeScores *gs, guint n, GdkColor *col)
@@ -288,7 +267,7 @@ gnome_scores_set_color(GnomeScores *gs, guint n, GdkColor *col)
 	gtk_widget_set_style(GTK_WIDGET(gs->_priv->label_scores[n]), s);
 	gtk_widget_set_style(GTK_WIDGET(gs->_priv->label_times[n]), s);
 
-	gtk_style_unref(s);
+	g_object_unref (G_OBJECT (s));
 }
 
 /**
@@ -297,8 +276,6 @@ gnome_scores_set_color(GnomeScores *gs, guint n, GdkColor *col)
  * @col: Color
  *
  * Description: Set the default color of the entries.
- *
- * Returns:
  */
 void
 gnome_scores_set_def_color(GnomeScores *gs, GdkColor *col)
@@ -320,8 +297,6 @@ gnome_scores_set_def_color(GnomeScores *gs, GdkColor *col)
  * @col: Array of colors.
  *
  * Description: Set the color of all the entries.
- *
- * Returns:
  */
 void
 gnome_scores_set_colors(GnomeScores *gs, GdkColor *col)
@@ -343,8 +318,6 @@ gnome_scores_set_colors(GnomeScores *gs, GdkColor *col)
  * @i: Index of the current(from 0 to 9).
  *
  * Description: Set the index of the current player in top ten.
- *
- * Returns:
  */
 void
 gnome_scores_set_current_player (GnomeScores *gs, gint i)
@@ -364,8 +337,6 @@ gnome_scores_set_current_player (GnomeScores *gs, gint i)
  * @txt: Name of the logo.
  *
  * Description: Creates a label to be the logo
- *
- * Returns:
  */
 void
 gnome_scores_set_logo_label_title (GnomeScores *gs, const gchar *txt)
@@ -394,8 +365,6 @@ gnome_scores_set_logo_label_title (GnomeScores *gs, const gchar *txt)
  * @col: Color to use in the label.
  *
  * Description: Creates a label to be the logo
- *
- * Returns:
  */
 void
 gnome_scores_set_logo_label (GnomeScores *gs,
@@ -405,8 +374,7 @@ gnome_scores_set_logo_label (GnomeScores *gs,
 {
 	GtkStyle *s = gtk_style_new(); /* i believe that i should copy the default style
 					  and change only the fg & font fields, how? */
-	GdkFont *f;
-	const gchar *fo;
+	PangoFontDescription *font_desc;
 
 	g_return_if_fail(gs != NULL);
 	g_return_if_fail(GNOME_IS_SCORES(gs));
@@ -419,17 +387,17 @@ gnome_scores_set_logo_label (GnomeScores *gs,
 	if(col)
 		s->fg[0] = *col;
 
-	if( font ) 
-		fo = font;
-	else 
-		fo = _("-freefont-garamond-*-*-*-*-30-170-*-*-*-*-*-*,*-r-*");
-
-	if(( f = gdk_fontset_load ( fo ) ))
-		gtk_style_set_font(s, f);
+	font_desc = NULL;
+	if (font != NULL)
+		font_desc = pango_font_description_from_string (font);
+	if (font_desc == NULL)
+		font_desc = pango_font_description_from_string (_("Sans 14"));
+	if (font_desc != NULL)
+		s->font_desc = font_desc;
 
 	gs->_priv->logo = gtk_label_new(txt);
 	gtk_widget_set_style(GTK_WIDGET(gs->_priv->logo), s);
-	gtk_style_unref(s);
+	g_object_unref (G_OBJECT (s));
 	gtk_container_add(GTK_CONTAINER(gs->_priv->logo_container), gs->_priv->logo);
 	gtk_widget_show (gs->_priv->logo);
 }
@@ -440,8 +408,6 @@ gnome_scores_set_logo_label (GnomeScores *gs,
  * @w: Widget to be used as logo.
  *
  * Description:  Set an arbitrary widget to be the logo.
- *
- * Returns:
  */
 void
 gnome_scores_set_logo_widget (GnomeScores *gs, GtkWidget *w)
@@ -468,8 +434,6 @@ gnome_scores_set_logo_widget (GnomeScores *gs, GtkWidget *w)
  * @pix_name: filename of a pixmap
  *
  * Description:  Sets the logo on the scores dialog box to a pixmap
- *
- * Returns:
  */
 void
 gnome_scores_set_logo_pixmap (GnomeScores *gs, const gchar *pix_name)
@@ -498,9 +462,10 @@ gnome_scores_set_logo_pixmap (GnomeScores *gs, const gchar *pix_name)
  * @level: Level of the game or %NULL.
  * @pos: Position in the top ten of the current player, as returned by gnome_score_log.
  *
- * Description:  Does all the work of displaying the best scores. 
+ * Description:  Does all the work of displaying the best scores.
  * It calls gnome_score_get_notables to retrieve the info, creates the window,
- * and show it.
+ * and show it. If there are no scores nothing is displayed and the recommended practise
+ * is to disable the scores menu entry in this case.
  *
  * Returns:  If a dialog is displayed return it's pointer.  It can also
  * be %NULL if no dialog is displayed
@@ -520,12 +485,13 @@ gnome_scores_display (const gchar *title, const gchar *app_name, const gchar *le
 		gnome_scores_set_logo_label_title (GNOME_SCORES(hs), title);
 		if(pos)
  			gnome_scores_set_current_player(GNOME_SCORES(hs), pos-1);
-		
+
 		gtk_widget_show (hs);
-		g_strfreev(names);
-		g_free(scores);
-		g_free(scoretimes);
-	} 
+	}
+
+	g_strfreev(names);
+	g_free(scores);
+	g_free(scoretimes);
 
 	return hs;
 }
@@ -537,7 +503,7 @@ gnome_scores_display (const gchar *title, const gchar *app_name, const gchar *le
  * @level: Level of the game or %NULL.
  * @pos: Position in the top ten of the current player, as returned by gnome_score_log.
  *
- * Description:  Does all the work of displaying the best scores. 
+ * Description:  Does all the work of displaying the best scores.
  * It calls gnome_score_get_notables to retrieve the info, creates the window,
  * and show it.
  *
@@ -559,12 +525,13 @@ gnome_scores_display_with_pixmap (const gchar *pixmap_logo, const gchar *app_nam
 		gnome_scores_set_logo_pixmap (GNOME_SCORES(hs), pixmap_logo);
 		if(pos)
  			gnome_scores_set_current_player(GNOME_SCORES(hs), pos-1);
-		
+
 		gtk_widget_show (hs);
-		g_strfreev(names);
-		g_free(scores);
-		g_free(scoretimes);
-	} 
+	}
+
+	g_strfreev(names);
+	g_free(scores);
+	g_free(scoretimes);
 
 	return hs;
 }
